@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "web-mode" "17.3.20"
+(define-package "web-mode" "20250827.1315"
   "Major mode for editing web templates."
   '((emacs "23.1"))
   :url "https://web-mode.org"
-  :commit "0c83581d1e93d1d802c730a1d5e90cd1c740e1b2"
-  :revdesc "0c83581d1e93"
+  :commit "1eb0abb1a9bffbb33db7bbfc6efe5b48bf416d57"
+  :revdesc "1eb0abb1a9bf"
   :keywords '("languages")
   :maintainers '(("François-Xavier Bois" . "fxbois@gmail.com")))
